# Generated by Django 4.1.10 on 2023-10-27 08:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geomanager', '0026_layerrasterfile_raster_metadata_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='layerrasterfile',
            options={'ordering': ['-time'], 'verbose_name': 'Layer Raster File', 'verbose_name_plural': 'Layer Raster Files'},
        ),
        migrations.AddField(
            model_name='rasterfilelayer',
            name='date_format',
            field=models.CharField(blank=True, choices=[('yyyy-MM-dd HH:mm', 'Hour minute:second - (E.g 2023-01-01 00:00)'), ('yyyy-MM-dd', 'Day - (E.g 2023-01-01)'), ('yyyy-MM', 'Month number - (E.g 2023-01)'), ('MMMM yyyy', 'Month name - (E.g January 2023)'), ('pentadal', 'Pentadal - (E.g Jan 2023 - P1 1-5th)')], default='yyyy-MM-dd HH:mm', max_length=100, null=True, verbose_name='Display Format for DateTime Selector'),
        ),
        migrations.AddField(
            model_name='rastertilelayer',
            name='date_format',
            field=models.CharField(blank=True, choices=[('yyyy-MM-dd HH:mm', 'Hour minute:second - (E.g 2023-01-01 00:00)'), ('yyyy-MM-dd', 'Day - (E.g 2023-01-01)'), ('yyyy-MM', 'Month number - (E.g 2023-01)'), ('MMMM yyyy', 'Month name - (E.g January 2023)'), ('pentadal', 'Pentadal - (E.g Jan 2023 - P1 1-5th)')], max_length=100, null=True, verbose_name='Display Format for DateTime Selector'),
        ),
        migrations.AddField(
            model_name='vectortilelayer',
            name='date_format',
            field=models.CharField(blank=True, choices=[('yyyy-MM-dd HH:mm', 'Hour minute:second - (E.g 2023-01-01 00:00)'), ('yyyy-MM-dd', 'Day - (E.g 2023-01-01)'), ('yyyy-MM', 'Month number - (E.g 2023-01)'), ('MMMM yyyy', 'Month name - (E.g January 2023)'), ('pentadal', 'Pentadal - (E.g Jan 2023 - P1 1-5th)')], max_length=100, null=True, verbose_name='Display Format for DateTime Selector'),
        ),
        migrations.AlterField(
            model_name='wmslayer',
            name='date_format',
            field=models.CharField(blank=True, choices=[('yyyy-MM-dd HH:mm', 'Hour minute:second - (E.g 2023-01-01 00:00)'), ('yyyy-MM-dd', 'Day - (E.g 2023-01-01)'), ('yyyy-MM', 'Month number - (E.g 2023-01)'), ('MMMM yyyy', 'Month name - (E.g January 2023)'), ('pentadal', 'Pentadal - (E.g Jan 2023 - P1 1-5th)')], max_length=100, null=True, verbose_name='Display Format for DateTime Selector'),
        ),
    ]
