# Generated by Django 4.1.10 on 2023-11-01 10:54

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('geomanager', '0027_alter_layerrasterfile_options_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='pgvectortable',
            options={'ordering': ['-time'], 'verbose_name': 'Vector Upload', 'verbose_name_plural': 'Vector Uploads'},
        ),
        migrations.AlterField(
            model_name='dataset',
            name='category',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='datasets', to='geomanager.category', verbose_name='category'),
        ),
    ]
