# Generated by Django 4.2.1 on 2023-06-09 10:15

from django.db import migrations, models
import geomanager.models.raster_file
import wagtail.blocks
import wagtail.fields
import wagtail_color_panel.fields


class Migration(migrations.Migration):
    dependencies = [
        ('geomanager', '0002_geomanagersettings_logo_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='colorvalue',
            name='label',
            field=models.CharField(blank=True, max_length=100, null=True, verbose_name='Label for Legend'),
        ),
        migrations.AlterField(
            model_name='colorvalue',
            name='threshold',
            field=models.FloatField(
                help_text='Values less than or equal to the input value, will be assigned the chosen color',
                verbose_name='Threshold value'),
        ),
        migrations.AlterField(
            model_name='geomanagersettings',
            name='navigation',
            field=wagtail.fields.StreamField([('menu_items', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock(
                [('label', wagtail.blocks.CharBlock(label='Label')),
                 ('page', wagtail.blocks.PageChooserBlock(label='Page'))], max_num=8)))], blank=True, null=True,
                                             use_json_field=True),
        ),
        migrations.AlterField(
            model_name='layerrasterfile',
            name='file',
            field=models.FileField(upload_to=geomanager.models.raster_file.layer_raster_file_dir_path, verbose_name='file'),
        ),
        migrations.AlterField(
            model_name='rasterstyle',
            name='custom_color_for_rest',
            field=wagtail_color_panel.fields.ColorField(blank=True, default='#ff0000',
                                                        help_text='Color for values greater than the values defined above, as well as values greater than the maximum defined value',
                                                        max_length=7, null=True,
                                                        verbose_name='Color for the rest of values'),
        ),
    ]
