# Generated by Django 4.1.10 on 2023-09-19 15:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geomanager', '0014_geomanagersettings_privacy_policy_page_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='wmslayer',
            name='request_time_from_capabilities',
            field=models.BooleanField(default=True, help_text='Get list of available times for this layer from getCapabilities', verbose_name='Request time from capabilities'),
        ),
    ]
