# Generated by Django 4.1.10 on 2023-08-01 11:52

from django.db import migrations, models
import django.db.models.deletion
import wagtail.blocks
import wagtail.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0083_workflowcontenttype'),
        ('geomanager', '0012_geomanagersettings_crop_raster_to_country'),
    ]

    operations = [
        migrations.AddField(
            model_name='geomanagersettings',
            name='logo_external_link',
            field=models.URLField(blank=True, help_text='Used if internal page not provided', max_length=255, null=True, verbose_name='Logo external link'),
        ),
        migrations.AddField(
            model_name='geomanagersettings',
            name='logo_page',
            field=models.ForeignKey(blank=True, help_text='Internal page to navigate to on clicking the logo', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailcore.page', verbose_name='Logo internal page link'),
        ),
        migrations.AlterField(
            model_name='geomanagersettings',
            name='navigation',
            field=wagtail.fields.StreamField([('menu_items', wagtail.blocks.ListBlock(wagtail.blocks.StructBlock([('label', wagtail.blocks.CharBlock(label='Label')), ('page', wagtail.blocks.PageChooserBlock(help_text='Internal page to navigate', label='Page', required=False)), ('external_link', wagtail.blocks.URLBlock(label='External link to navigate to. Used if internal page not provided', required=False))], max_num=8)))], blank=True, null=True, use_json_field=True),
        ),
    ]
