# Generated by Django 4.1.10 on 2023-11-15 10:07

from django.db import migrations, models
import geomanager.models.raster_file
import geomanager.storage


class Migration(migrations.Migration):

    dependencies = [
        ('geomanager', '0032_rasterfilelayer_auto_ingest_nc_data_variable'),
    ]

    operations = [
        migrations.AlterField(
            model_name='layerrasterfile',
            name='file',
            field=models.FileField(storage=geomanager.storage.OverwriteStorage, upload_to=geomanager.models.raster_file.layer_raster_file_dir_path, verbose_name='file'),
        ),
        migrations.AlterField(
            model_name='rasterfilelayer',
            name='auto_ingest_nc_data_variable',
            field=models.CharField(blank=True, help_text='The name of the data variable to use, if ingesting from netCDF files', max_length=100, null=True, verbose_name='Data variable for netCDF data auto ingest'),
        ),
    ]
