# Generated by Django 4.1.10 on 2023-09-19 16:43

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geomanager', '0015_wmslayer_request_time_from_capabilities'),
    ]

    operations = [
        migrations.AddField(
            model_name='wmslayer',
            name='date_format',
            field=models.CharField(blank=True, choices=[('yyyy-mm-dd HH:MM', 'Hourly (2023-01-01 00:00)'), ('yyyy-mm-dd', 'Year-Month-Day (2023-01-01)'), ('yyyy-mm', 'Year-Month (2023-01-01)'), ('mm yyyy', 'MonthName Year (January 2023)'), ('pentadal', 'MonthName Year - Pentad number Dates  (Jan 2023 - P1 1-5th)')], default='yyyy-mm-dd HH:MM', max_length=100, null=True),
        ),
    ]
