# Generated by Django 4.1.10 on 2023-09-20 08:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('geomanager', '0018_wmslayer_custom_get_capabilities_url'),
    ]

    operations = [
        migrations.AddField(
            model_name='wmslayer',
            name='get_capabilities_layer_name',
            field=models.CharField(blank=True, help_text='Alternative layer name for the GetCapabilities request', max_length=255, null=True, verbose_name='Get Capabilities Layer Name'),
        ),
        migrations.AlterField(
            model_name='wmslayer',
            name='custom_get_capabilities_url',
            field=models.URLField(blank=True, help_text="Alternative URL for the GetCapabilities request. Used when 'Request time from capabilities' option is checked. Leave blank to use base url.", null=True, verbose_name='Get Capabilities URL'),
        ),
    ]
